@@ -11,6 +11,8 @@
 #	include <getopt.h>
 #endif
 
+#include <stdio.h>
+
 #include "cmdline2.h"
 
 int
@@ -22,5 +24,17 @@ main (int argc, char **argv)
   if (my_cmdline_parser (argc, argv, &args_info) != 0)
     exit(1) ;
 
+  if (args_info.help_given)
+    {
+      printf ("This is a simple test for gengetopt\n");
+      my_cmdline_parser_print_help ();
+    }
+
+  if (args_info.version_given)
+    {
+      printf ("Here is the version\n");
+      my_cmdline_parser_print_version ();
+    }
+
   return 0;
 }
