@@ -15,6 +15,7 @@ This file is licensed to you under the license specified in the included file
 extern struct gengetopt_option * gengetopt_options;
 extern char * gengetopt_package;
 extern char * gengetopt_version;
+extern char * gengetopt_purpose;
 
 static int tab_indentation ; /* tab indentation level */
 
@@ -29,6 +30,8 @@ static void check_option_given( char *var_arg,
 #define ARGS_STRUCT "args_info"
 #define ARGS_STRUCT_NAME PACKAGE "_" ARGS_STRUCT
 
+static char *parser_function_name;
+
 long
 gengetopt_strlen (char *s)
 {
@@ -144,18 +147,24 @@ do_check_option_given (struct gengetopt_option *opt)
 int
 generate_cmdline_parser (char *function_name, short unamed_options,
                          char *filename, char *header_ext, char *c_ext,
-                         int long_help, char **comment)
+                         int long_help, int no_handle_help,
+                         int no_handle_version, char **comment)
 {
   long max_long, max_short, w;
   struct gengetopt_option * opt;
   char *comment_string ;
   int i ;
   int first_time = 1;
+  
+  short generate_strdup = unamed_options;
+  /* if unamed_options is specified gengetopt_strdup has to be generated;
+     otherwise it will be only if a string option is specified */
 
   FILE *output_file ;
 
   char *header_filename ;
   char *c_filename ;
+  parser_function_name = function_name; /* initialize static data */
 
   header_filename = create_filename (filename, header_ext) ;
   c_filename = create_filename (filename, c_ext) ;
@@ -302,6 +311,9 @@ generate_cmdline_parser (char *function_name, short unamed_options,
   printf ("int %s (int argc, char * const *argv, struct %s *%s);\n\n", 
           function_name, ARGS_STRUCT_NAME, ARGS_STRUCT);
 
+  printf ("void %s_print_help(void);\n", function_name);
+  printf ("void %s_print_version(void);\n\n", function_name);
+
   printf ("#ifdef __cplusplus\n");
   printf ("}\n");
   printf ("#endif /* __cplusplus */\n");
@@ -357,19 +369,35 @@ generate_cmdline_parser (char *function_name, short unamed_options,
 header_filename);
 
   printf ("\n"
-"static void\n"
-"print_version (void)\n"
+"void\n"
+"%s_print_version (void)\n"
 "{\n"
 "  printf (\"%%s %%s\\n\", PACKAGE, VERSION);\n"
 "}\n"
 "\n"
-"static void\n"
-"print_help (void)\n"
+"void\n"
+"%s_print_help (void)\n"
 "{\n"
-"  print_version ();\n"
-"  printf (\""
-"Usage: %%s "
-);
+"  %s_print_version ();\n", function_name, function_name, function_name);
+  printf ("  printf(\"\\n\"\n");
+  if (gengetopt_purpose != NULL) {
+    char *ptr;
+    ptr = gengetopt_purpose;
+    printf (
+"\"Purpose:\\n\"\n"
+"\"  ");
+    for (; *ptr!='\0'; ptr++) {
+      if (*ptr == '\n') {
+	printf("\\n\"\n\"  ");
+      } else {
+	printf("%c", *ptr);
+      }
+    }
+    printf (""
+"\\n\"\n"
+"\"\\n\"\n");
+  }
+  printf ("\"Usage: %%s ");
 
 
 
@@ -496,26 +524,32 @@ header_filename);
 	}
   printf ("\", PACKAGE);\n}\n\n\n");
 
-  foropt
+  if (! generate_strdup)
+    {
+      foropt
 	if (opt->type == ARG_STRING) {
-		printf (
-"static char *\n"
-"gengetopt_strdup (char * s)\n"
-"{\n"
-"  char * n, * pn, * ps = s;\n"
-"  while (*ps) ps++;\n"
-"  n = (char *) malloc (1 + ps - s);\n"
-"  if (n != NULL)\n"
-"    {\n"
-"      for (ps=s,pn=n; *ps; ps++,pn++)\n"
-"        *pn = *ps;\n"
-"      *pn = 0;\n"
-"    }\n"
-"  return n;\n"
-"}\n\n\n");
-		break;
+          generate_strdup = 1;
+          break;
 	}
+    }
 
+  if (generate_strdup)
+    printf (
+            "static char *\n"
+            "gengetopt_strdup (char * s)\n"
+            "{\n"
+            "  char * n, * pn, * ps = s;\n"
+            "  while (*ps) ps++;\n"
+            "  n = (char *) malloc (1 + ps - s);\n"
+            "  if (n != NULL)\n"
+            "    {\n"
+            "      for (ps=s,pn=n; *ps; ps++,pn++)\n"
+            "        *pn = *ps;\n"
+            "      *pn = 0;\n"
+            "    }\n"
+            "  return n;\n"
+            "}\n\n\n");
+  
   printf (
 "int\n"
 "%s (int argc, char * const *argv, struct %s *%s)\n"
@@ -615,28 +649,39 @@ inc_indent ();
   printf ("switch (c)\n");
   inc_indent ();
   indent ();
-  printf ("{\n");
-  indent ();
-  printf ("case 'h':\t/* Print help and exit.  */\n");
-  inc_indent ();
-  indent ();
-  printf ("clear_args ();\n");
-  indent ();
-  printf ("print_help ();\n");
-  indent ();
-  printf ("exit (0);\n\n");
+  printf ("{");
 
-  dec_indent ();
-  indent ();
-  printf ("case 'V':\t/* Print version and exit.  */\n");
-  inc_indent ();
-  indent ();
-  printf ("clear_args ();\n");
-  indent ();
-  printf ("print_version ();\n");
-  indent ();
-  printf ("exit (0);\n");
-  dec_indent ();
+  if (! no_handle_help)
+    {
+      printf ("\n");
+      indent ();
+      printf ("case 'h':\t/* Print help and exit.  */\n");
+      inc_indent ();
+      indent ();
+      
+      printf ("clear_args ();\n");
+      indent ();
+      printf ("%s_print_help ();\n", function_name);
+      indent ();
+      printf ("exit (0);\n");
+
+      dec_indent ();
+    }
+
+  if (! no_handle_version)
+    {
+      printf ("\n");
+      indent ();
+      printf ("case 'V':\t/* Print version and exit.  */\n");
+      inc_indent ();
+      indent ();
+      printf ("clear_args ();\n");
+      indent ();
+      printf ("%s_print_version ();\n", function_name);
+      indent ();
+      printf ("exit (0);\n");
+      dec_indent ();
+    }
 
   /* ****************************************************** */
   /* ********************************************* GENERATE */
@@ -644,7 +689,11 @@ inc_indent ();
 
 
   foropt {
-    if (opt->short_opt == 'h' || opt->short_opt == 'V') continue;
+    if (
+        (opt->short_opt == 'h' && ! no_handle_help) || 
+        (opt->short_opt == 'V' && ! no_handle_version)
+        ) 
+      continue;
 
     printf ("\n");
     indent ();
@@ -655,7 +704,12 @@ inc_indent ();
         inc_indent ();
         do_check_option_given (opt);
         indent ();
-        printf ("break;\n");
+
+        if (opt->short_opt == 'h' || opt->short_opt == 'V')
+          printf ("return 0;\n");
+        else
+          printf ("break;\n");
+
         dec_indent ();
     }
   }
@@ -763,14 +817,16 @@ inc_indent ();
       indent ();
       printf ("%s->inputs = \n", ARGS_STRUCT);
       indent ();
-      printf ("  (char **)(malloc ((%s->inputs_num)*sizeof(char *))) ;\n", ARGS_STRUCT);
+      printf ("  (char **)(malloc ((%s->inputs_num)*sizeof(char *))) ;\n", 
+              ARGS_STRUCT);
 
       indent ();
       printf ("while (optind < argc)\n");
 
       inc_indent ();
       indent ();
-      printf ("%s->inputs[ i++ ] = strdup (argv[optind++]) ; \n", ARGS_STRUCT);
+      printf ("%s->inputs[ i++ ] = gengetopt_strdup (argv[optind++]) ; \n", 
+              ARGS_STRUCT);
 
       dec_indent ();
       dec_indent ();
@@ -824,7 +880,7 @@ check_option_given( char *var_arg, char *long_opt, char short_opt )
   indent ();
   printf ("clear_args ();\n");
   indent ();
-  printf ("print_help ();\n");
+  printf ("%s_print_help ();\n", parser_function_name);
   indent ();
   printf ("exit (1);\n");
   dec_indent ();
