@@ -5,6 +5,8 @@
 
 int generate_cmdline_parser (char *name, short handle_unamed_options,
                              char *filename, char *header_ext, char *c_ext,
-                             int long_help, char **comment) ;
+                             int long_help, 
+                             int no_handle_help,
+                             int no_handle_version, char **comment) ;
 
 #endif /* _GM_H */
