@@ -1,20 +1,21 @@
 
 /*  A Bison parser, made from parser.y
- by  GNU Bison version 1.25
-  */
+    by GNU Bison version 1.28  */
 
 #define YYBISON 1  /* Identify Bison output.  */
 
-#define	TOK_PACKAGE	258
-#define	TOK_VERSION	259
-#define	TOK_OPTION	260
-#define	TOK_YES	261
-#define	TOK_NO	262
-#define	TOK_FLAG	263
+#define	TOK_PACKAGE	257
+#define	TOK_VERSION	258
+#define	TOK_OPTION	259
+#define	TOK_YES	260
+#define	TOK_NO	261
+#define	TOK_FLAG	262
+#define	TOK_PURPOSE	263
 #define	TOK_ONOFF	264
 #define	TOK_STRING	265
-#define	TOK_CHAR	266
-#define	TOK_ARGTYPE	267
+#define	TOK_MLSTRING	266
+#define	TOK_CHAR	267
+#define	TOK_ARGTYPE	268
 
 #line 7 "parser.y"
 
@@ -29,6 +30,7 @@ extern int gengetopt_count_line;
 
 static int gengetopt_package_given = 0;
 static int gengetopt_version_given = 0;
+static int gengetopt_purpose_given = 0;
 
 extern void yyerror ( char *error ) ;
 extern int yylex () ;
@@ -37,7 +39,7 @@ extern int yylex () ;
 #define check_result \
 	if (o) { switch (o) { case 1: yyerror ("not enough memory"); break; case 2: yyerror ("long option redefined"); break; case 3: yyerror ("short option redefined"); break; case 4: yyerror ("bug found!!"); break; } YYERROR; }
 
-#line 28 "parser.y"
+#line 29 "parser.y"
 typedef union {
 char * str;
 char chr;
@@ -54,14 +56,14 @@ int bool;
 
 
 
-#define	YYFINAL		23
+#define	YYFINAL		27
 #define	YYFLAG		-32768
-#define	YYNTBASE	14
+#define	YYNTBASE	16
 
-#define YYTRANSLATE(x) ((unsigned)(x) <= 267 ? yytranslate[x] : 19)
+#define YYTRANSLATE(x) ((unsigned)(x) <= 268 ? yytranslate[x] : 22)
 
 static const char yytranslate[] = {     0,
-     2,     2,     2,     2,     2,     2,     2,     2,     2,    13,
+     2,     2,     2,     2,     2,     2,     2,     2,     2,    15,
      2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
      2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
      2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
@@ -86,29 +88,30 @@ static const char yytranslate[] = {     0,
      2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
      2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
      2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
-     2,     2,     2,     2,     2,     1,     2,     3,     4,     5,
-     6,     7,     8,     9,    10,    11,    12
+     2,     2,     2,     2,     2,     1,     3,     4,     5,     6,
+     7,     8,     9,    10,    11,    12,    13,    14
 };
 
 #if YYDEBUG != 0
 static const short yyprhs[] = {     0,
-     0,     1,     4,     6,     9,    11,    13,    15,    18,    21,
-    27,    34
+     0,     1,     4,     6,     9,    11,    13,    15,    17,    20,
+    23,    26,    29,    35,    42
 };
 
 static const short yyrhs[] = {    -1,
-    14,    15,     0,    13,     0,    18,    13,     0,    10,     0,
-     6,     0,     7,     0,     3,    10,     0,     4,    10,     0,
-     5,    10,    11,    16,     7,     0,     5,    10,    11,    16,
-     8,     9,     0,     5,    10,    11,    16,    12,    17,     0
+    16,    17,     0,    15,     0,    21,    15,     0,    11,     0,
+    12,     0,     6,     0,     7,     0,     3,    11,     0,     4,
+    11,     0,     9,    19,     0,     9,    18,     0,     5,    11,
+    13,    18,     7,     0,     5,    11,    13,    18,     8,    10,
+     0,     5,    11,    13,    18,    14,    20,     0
 };
 
 #endif
 
 #if YYDEBUG != 0
 static const short yyrline[] = { 0,
-    52,    53,    57,    58,    62,    66,    67,    71,    75,    79,
-    83,    87
+    56,    57,    61,    62,    66,    69,    73,    74,    78,    82,
+    85,    88,    90,    94,    98
 };
 #endif
 
@@ -116,56 +119,60 @@ static const short yyrline[] = { 0,
 #if YYDEBUG != 0 || defined (YYERROR_VERBOSE)
 
 static const char * const yytname[] = {   "$","error","$undefined.","TOK_PACKAGE",
-"TOK_VERSION","TOK_OPTION","TOK_YES","TOK_NO","TOK_FLAG","TOK_ONOFF","TOK_STRING",
-"TOK_CHAR","TOK_ARGTYPE","'\\n'","input","line","exp_str","exp_yesno","exp", NULL
+"TOK_VERSION","TOK_OPTION","TOK_YES","TOK_NO","TOK_FLAG","TOK_PURPOSE","TOK_ONOFF",
+"TOK_STRING","TOK_MLSTRING","TOK_CHAR","TOK_ARGTYPE","'\\n'","input","line",
+"exp_str","exp_mlstr","exp_yesno","exp", NULL
 };
 #endif
 
 static const short yyr1[] = {     0,
-    14,    14,    15,    15,    16,    17,    17,    18,    18,    18,
-    18,    18
+    16,    16,    17,    17,    18,    19,    20,    20,    21,    21,
+    21,    21,    21,    21,    21
 };
 
 static const short yyr2[] = {     0,
-     0,     2,     1,     2,     1,     1,     1,     2,     2,     5,
-     6,     6
+     0,     2,     1,     2,     1,     1,     1,     1,     2,     2,
+     2,     2,     5,     6,     6
 };
 
 static const short yydefact[] = {     1,
-     0,     0,     0,     0,     3,     2,     0,     8,     9,     0,
-     4,     0,     5,     0,    10,     0,     0,    11,     6,     7,
-    12,     0,     0
+     0,     0,     0,     0,     0,     3,     2,     0,     9,    10,
+     0,     5,     6,    12,    11,     4,     0,     0,    13,     0,
+     0,    14,     7,     8,    15,     0,     0
 };
 
 static const short yydefgoto[] = {     1,
-     6,    14,    21,     7
+     7,    14,    15,    25,     8
 };
 
 static const short yypact[] = {-32768,
-     0,    -1,     2,     4,-32768,-32768,    -3,-32768,-32768,     5,
--32768,     7,-32768,    -6,-32768,     6,     1,-32768,-32768,-32768,
--32768,    11,-32768
+     0,     1,     2,     3,    -5,-32768,-32768,     5,-32768,-32768,
+     6,-32768,-32768,-32768,-32768,-32768,     7,    -6,-32768,    11,
+     4,-32768,-32768,-32768,-32768,    16,-32768
 };
 
 static const short yypgoto[] = {-32768,
--32768,-32768,-32768,-32768
+-32768,     8,-32768,-32768,-32768
 };
 
 
-#define	YYLAST		17
+#define	YYLAST		25
 
 
-static const short yytable[] = {    22,
-    15,    16,     2,     3,     4,    17,    19,    20,     8,    11,
-    23,     9,     5,    10,    18,    12,    13
+static const short yytable[] = {    26,
+    19,    20,     2,     3,     4,    12,    13,    21,     5,    23,
+    24,     9,    10,    11,     6,    27,     0,    12,    17,    16,
+    22,     0,     0,     0,    18
 };
 
 static const short yycheck[] = {     0,
-     7,     8,     3,     4,     5,    12,     6,     7,    10,    13,
-     0,    10,    13,    10,     9,    11,    10
+     7,     8,     3,     4,     5,    11,    12,    14,     9,     6,
+     7,    11,    11,    11,    15,     0,    -1,    11,    13,    15,
+    10,    -1,    -1,    -1,    17
 };
 /* -*-C-*-  Note some compilers choke on comments on `#line' lines.  */
-#line 3 "/usr/share/bison.simple"
+#line 3 "//usr/lib/bison.simple"
+/* This file comes from bison-1.28.  */
 
 /* Skeleton output parser for bison,
    Copyright (C) 1984, 1989, 1990 Free Software Foundation, Inc.
@@ -182,47 +189,67 @@ static const short yycheck[] = {     0,
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.  */
 
 /* As a special exception, when this file is copied by Bison into a
    Bison output file, you may use that output file without restriction.
    This special exception was added by the Free Software Foundation
    in version 1.24 of Bison.  */
 
-#ifndef alloca
-#ifdef __GNUC__
-#define alloca __builtin_alloca
-#else /* not GNU C.  */
-#if (!defined (__STDC__) && defined (sparc)) || defined (__sparc__) || defined (__sparc) || defined (__sgi)
-#include <alloca.h>
-#else /* not sparc */
-#if defined (MSDOS) && !defined (__TURBOC__)
-#include <malloc.h>
-#else /* not MSDOS, or __TURBOC__ */
-#if defined(_AIX)
-#include <malloc.h>
- #pragma alloca
-#else /* not MSDOS, __TURBOC__, or _AIX */
-#ifdef __hpux
-#ifdef __cplusplus
-extern "C" {
-void *alloca (unsigned int);
-};
-#else /* not __cplusplus */
-void *alloca ();
-#endif /* not __cplusplus */
-#endif /* __hpux */
-#endif /* not _AIX */
-#endif /* not MSDOS, or __TURBOC__ */
-#endif /* not sparc.  */
-#endif /* not GNU C.  */
-#endif /* alloca not defined.  */
-
 /* This is the parser code that is written into each bison parser
   when the %semantic_parser declaration is not specified in the grammar.
   It was written by Richard Stallman by simplifying the hairy parser
   used when %semantic_parser is specified.  */
 
+#ifndef YYSTACK_USE_ALLOCA
+#ifdef alloca
+#define YYSTACK_USE_ALLOCA
+#else /* alloca not defined */
+#ifdef __GNUC__
+#define YYSTACK_USE_ALLOCA
+#define alloca __builtin_alloca
+#else /* not GNU C.  */
+#if (!defined (__STDC__) && defined (sparc)) || defined (__sparc__) || defined (__sparc) || defined (__sgi) || (defined (__sun) && defined (__i386))
+#define YYSTACK_USE_ALLOCA
+#include <alloca.h>
+#else /* not sparc */
+/* We think this test detects Watcom and Microsoft C.  */
+/* This used to test MSDOS, but that is a bad idea
+   since that symbol is in the user namespace.  */
+#if (defined (_MSDOS) || defined (_MSDOS_)) && !defined (__TURBOC__)
+#if 0 /* No need for malloc.h, which pollutes the namespace;
+	 instead, just don't use alloca.  */
+#include <malloc.h>
+#endif
+#else /* not MSDOS, or __TURBOC__ */
+#if defined(_AIX)
+/* I don't know what this was needed for, but it pollutes the namespace.
+   So I turned it off.   rms, 2 May 1997.  */
+/* #include <malloc.h>  */
+ #pragma alloca
+#define YYSTACK_USE_ALLOCA
+#else /* not MSDOS, or __TURBOC__, or _AIX */
+#if 0
+#ifdef __hpux /* haible@ilog.fr says this works for HPUX 9.05 and up,
+		 and on HPUX 10.  Eventually we can turn this on.  */
+#define YYSTACK_USE_ALLOCA
+#define alloca __builtin_alloca
+#endif /* __hpux */
+#endif
+#endif /* not _AIX */
+#endif /* not MSDOS, or __TURBOC__ */
+#endif /* not sparc */
+#endif /* not GNU C */
+#endif /* alloca not defined */
+#endif /* YYSTACK_USE_ALLOCA not defined */
+
+#ifdef YYSTACK_USE_ALLOCA
+#define YYSTACK_ALLOC alloca
+#else
+#define YYSTACK_ALLOC malloc
+#endif
+
 /* Note: there must be only one dollar sign in this file.
    It is replaced by the list of actions, each action
    as one case of the switch.  */
@@ -231,8 +258,8 @@ void *alloca ();
 #define yyclearin	(yychar = YYEMPTY)
 #define YYEMPTY		-2
 #define YYEOF		0
-#define YYACCEPT	return(0)
-#define YYABORT 	return(1)
+#define YYACCEPT	goto yyacceptlab
+#define YYABORT 	goto yyabortlab
 #define YYERROR		goto yyerrlab1
 /* Like YYERROR except do call yyerror.
    This remains here temporarily to ease the
@@ -313,16 +340,12 @@ int yydebug;			/*  nonzero means print parse trace	*/
 #ifndef YYMAXDEPTH
 #define YYMAXDEPTH 10000
 #endif
-
-#ifndef YYPARSE_RETURN_TYPE
-#define YYPARSE_RETURN_TYPE int
-#endif
-
-/* Prevent warning if -Wstrict-prototypes.  */
-#ifdef __GNUC__
-YYPARSE_RETURN_TYPE yyparse (void);
-#endif
 
+/* Define __yy_memcpy.  Note that the size argument
+   should be passed with type unsigned int, because that is what the non-GCC
+   definitions require.  With GCC, __builtin_memcpy takes an arg
+   of type size_t, but it can handle unsigned int.  */
+
 #if __GNUC__ > 1		/* GNU C and GNU C++ define this.  */
 #define __yy_memcpy(TO,FROM,COUNT)	__builtin_memcpy(TO,FROM,COUNT)
 #else				/* not GNU C or C++ */
@@ -334,7 +357,7 @@ static void
 __yy_memcpy (to, from, count)
      char *to;
      char *from;
-     int count;
+     unsigned int count;
 {
   register char *f = from;
   register char *t = to;
@@ -349,10 +372,10 @@ __yy_memcpy (to, from, count)
 /* This is the most reliable way to avoid incompatibilities
    in available built-in functions on various systems.  */
 static void
-__yy_memcpy (char *to, char *from, int count)
+__yy_memcpy (char *to, char *from, unsigned int count)
 {
-  register char *f = from;
   register char *t = to;
+  register char *f = from;
   register int i = count;
 
   while (i-- > 0)
@@ -362,7 +385,7 @@ __yy_memcpy (char *to, char *from, int count)
 #endif
 #endif
 
-#line 196 "/usr/share/bison.simple"
+#line 217 "//usr/lib/bison.simple"
 
 /* The user can define YYPARSE_PARAM as the name of an argument to be passed
    into yyparse.  The argument should have type void *.
@@ -383,7 +406,16 @@ __yy_memcpy (char *to, char *from, int count)
 #define YYPARSE_PARAM_DECL
 #endif /* not YYPARSE_PARAM */
 
-YYPARSE_RETURN_TYPE
+/* Prevent warning if -Wstrict-prototypes.  */
+#ifdef __GNUC__
+#ifdef YYPARSE_PARAM
+int yyparse (void *);
+#else
+int yyparse (void);
+#endif
+#endif
+
+int
 yyparse(YYPARSE_PARAM_ARG)
      YYPARSE_PARAM_DECL
 {
@@ -411,6 +443,7 @@ yyparse(YYPARSE_PARAM_ARG)
 #endif
 
   int yystacksize = YYINITDEPTH;
+  int yyfree_stacks = 0;
 
 #ifdef YYPURE
   int yychar;
@@ -495,18 +528,32 @@ yynewstate:
       if (yystacksize >= YYMAXDEPTH)
 	{
 	  yyerror("parser stack overflow");
+	  if (yyfree_stacks)
+	    {
+	      free (yyss);
+	      free (yyvs);
+#ifdef YYLSP_NEEDED
+	      free (yyls);
+#endif
+	    }
 	  return 2;
 	}
       yystacksize *= 2;
       if (yystacksize > YYMAXDEPTH)
 	yystacksize = YYMAXDEPTH;
-      yyss = (short *) alloca (yystacksize * sizeof (*yyssp));
-      __yy_memcpy ((char *)yyss, (char *)yyss1, size * sizeof (*yyssp));
-      yyvs = (YYSTYPE *) alloca (yystacksize * sizeof (*yyvsp));
-      __yy_memcpy ((char *)yyvs, (char *)yyvs1, size * sizeof (*yyvsp));
+#ifndef YYSTACK_USE_ALLOCA
+      yyfree_stacks = 1;
+#endif
+      yyss = (short *) YYSTACK_ALLOC (yystacksize * sizeof (*yyssp));
+      __yy_memcpy ((char *)yyss, (char *)yyss1,
+		   size * (unsigned int) sizeof (*yyssp));
+      yyvs = (YYSTYPE *) YYSTACK_ALLOC (yystacksize * sizeof (*yyvsp));
+      __yy_memcpy ((char *)yyvs, (char *)yyvs1,
+		   size * (unsigned int) sizeof (*yyvsp));
 #ifdef YYLSP_NEEDED
-      yyls = (YYLTYPE *) alloca (yystacksize * sizeof (*yylsp));
-      __yy_memcpy ((char *)yyls, (char *)yyls1, size * sizeof (*yylsp));
+      yyls = (YYLTYPE *) YYSTACK_ALLOC (yystacksize * sizeof (*yylsp));
+      __yy_memcpy ((char *)yyls, (char *)yyls1,
+		   size * (unsigned int) sizeof (*yylsp));
 #endif
 #endif /* no yyoverflow */
 
@@ -667,40 +714,52 @@ yyreduce:
   switch (yyn) {
 
 case 5:
-#line 62 "parser.y"
+#line 66 "parser.y"
 { yyval.str = yyvsp[0].str; ;
     break;}
 case 6:
-#line 66 "parser.y"
-{ yyval.bool = 1; ;
+#line 69 "parser.y"
+{ yyval.str = yyvsp[0].str; ;
     break;}
 case 7:
-#line 67 "parser.y"
-{ yyval.bool = 0; ;
+#line 73 "parser.y"
+{ yyval.bool = 1; ;
     break;}
 case 8:
-#line 71 "parser.y"
-{ if (gengetopt_package_given) { yyerror ("package redefined"); YYERROR; } else { gengetopt_package_given = 1; if (gengetopt_define_package (yyvsp[0].str)) { yyerror ("not enough memory"); YYERROR; } } ;
+#line 74 "parser.y"
+{ yyval.bool = 0; ;
     break;}
 case 9:
-#line 75 "parser.y"
-{ if (gengetopt_version_given) { yyerror ("version redefined"); YYERROR; } else { gengetopt_version_given = 1; if (gengetopt_define_version (yyvsp[0].str)) { yyerror ("not enough memory"); YYERROR; } } ;
+#line 78 "parser.y"
+{ if (gengetopt_package_given) { yyerror ("package redefined"); YYERROR; } else { gengetopt_package_given = 1; if (gengetopt_define_package (yyvsp[0].str)) { yyerror ("not enough memory"); YYERROR; } } ;
     break;}
 case 10:
-#line 79 "parser.y"
-{ int o = gengetopt_add_option (yyvsp[-3].str, yyvsp[-2].chr, yyvsp[-1].str, ARG_NO, 0, 0); check_result; ;
+#line 82 "parser.y"
+{ if (gengetopt_version_given) { yyerror ("version redefined"); YYERROR; } else { gengetopt_version_given = 1; if (gengetopt_define_version (yyvsp[0].str)) { yyerror ("not enough memory"); YYERROR; } } ;
     break;}
 case 11:
-#line 83 "parser.y"
-{ int o = gengetopt_add_option (yyvsp[-4].str, yyvsp[-3].chr, yyvsp[-2].str, ARG_FLAG, yyvsp[0].bool, 0); check_result; ;
+#line 85 "parser.y"
+{ if (gengetopt_purpose_given) { yyerror ("purpose redefined"); YYERROR; } else { gengetopt_purpose_given = 1; if (gengetopt_define_purpose (yyvsp[0].str)) { yyerror ("not enough memory"); YYERROR; } } ;
     break;}
 case 12:
-#line 87 "parser.y"
+#line 88 "parser.y"
+{ if (gengetopt_purpose_given) { yyerror ("purpose redefined"); YYERROR; } else { gengetopt_purpose_given = 1; if (gengetopt_define_purpose (yyvsp[0].str)) { yyerror ("not enough memory"); YYERROR; } } ;
+    break;}
+case 13:
+#line 90 "parser.y"
+{ int o = gengetopt_add_option (yyvsp[-3].str, yyvsp[-2].chr, yyvsp[-1].str, ARG_NO, 0, 0); check_result; ;
+    break;}
+case 14:
+#line 94 "parser.y"
+{ int o = gengetopt_add_option (yyvsp[-4].str, yyvsp[-3].chr, yyvsp[-2].str, ARG_FLAG, yyvsp[0].bool, 0); check_result; ;
+    break;}
+case 15:
+#line 98 "parser.y"
 { int o = gengetopt_add_option (yyvsp[-4].str, yyvsp[-3].chr, yyvsp[-2].str, yyvsp[-1].argtype, 0, yyvsp[0].bool); check_result; ;
     break;}
 }
    /* the action file gets copied in in place of this dollarsign */
-#line 498 "/usr/share/bison.simple"
+#line 543 "//usr/lib/bison.simple"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -895,8 +954,32 @@ yyerrhandle:
 
   yystate = yyn;
   goto yynewstate;
+
+ yyacceptlab:
+  /* YYACCEPT comes here.  */
+  if (yyfree_stacks)
+    {
+      free (yyss);
+      free (yyvs);
+#ifdef YYLSP_NEEDED
+      free (yyls);
+#endif
+    }
+  return 0;
+
+ yyabortlab:
+  /* YYABORT comes here.  */
+  if (yyfree_stacks)
+    {
+      free (yyss);
+      free (yyvs);
+#ifdef YYLSP_NEEDED
+      free (yyls);
+#endif
+    }
+  return 1;
 }
-#line 91 "parser.y"
+#line 102 "parser.y"
 
 
 
